//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by winboard.rc
//
#define MANIFEST_RESOURCE_ID              1
#define IDM_NewGame                     100
#define IDM_LoadGame                    101
#define IDM_SaveGame                    102
#define IDM_Exit                        103
#define IDM_LoadPosition                104
#define IDM_SavePosition                105
#define IDM_EditPosition                106
#define IDM_FlipView                    107
#define IDM_MachineWhite                108
#define IDM_MachineBlack                109
#define IDM_TwoMachines                 110
#define IDM_EditGame                    111
#define IDM_Forward                     112
#define IDM_Backward                    113
#define IDM_ToEnd                       114
#define IDM_ToStart                     115
#define IDM_Pause                       116
#define IDM_CallFlag                    117
#define IDM_Draw                        118
#define IDM_SaveDiagram                 119
#define IDM_Abort                       120
#define IDM_Adjourn                     122
#define IDM_Resign                      124
#define IDM_Hint                        125
#define IDM_IcsClient                   126
#define IDM_TimeControl                 131
#define IDM_LoadOptions                 132
#define IDM_SaveOptions                 133
#define IDM_EditGame2                   134
#define IDM_EditPosition2               135
#define IDM_CommPort                    147
#define IDM_EditComment                 148
#define IDM_LoadNextGame                149
#define IDM_LoadPrevGame                150
#define IDM_ReloadGame                  151
#define IDM_Accept                      153
#define IDM_Decline                     154
#define IDM_StopObserving               155
#define IDM_StopExamining               156
#define IDM_Revert                      157
#define IDM_TruncateGame                158
#define IDM_MoveNow                     159
#define IDM_RetractMove                 160
#define IDM_Upload                      161
#define IDM_MailMove                    164
#define IDM_ReloadCMailMsg              165
#define IDM_Book                        166
#define IDM_AboutGame                   167
#define IDM_EditServers                 169
#define IDM_ShowGameList                170
#define IDM_EditTags                    171
#define IDM_Tags                        172
#define IDM_Comment                     173
#define IDM_Debug                       174
#define IDM_EditProgs1                  175
#define IDM_EditProgs2                  176
#define IDM_AnalysisMode                177
#define IDM_AnalyzeFile                 178
#define IDM_Annotate                    179
#define IDM_CopyGame                    180
#define IDM_PasteGame                   181
#define IDM_CopyPosition                182
#define IDM_PastePosition               183
#define IDM_NewVariant                  184  
#define IDM_TypeInName                  185  
#define IDM_MachineBoth                 186  
#define IDM_MuteSounds                  187
#define IDM_Match                       188
#define OPT_TCtext1                     202
#define OPT_TCTime                      203
#define OPT_TCtext2                     204
#define OPT_Autosave                    206
#define OPT_AVPrompt                    208
#define OPT_AVToFile                    209
#define OPT_AVFilename                  210
#define OPT_Autostep                    214
#define OPT_ASTimeDelay                 215
#define OPT_AStext1                     216
#define OPT_TCMoves                     217
#define IDM_HELPCONTENTS                300
#define IDM_HELPSEARCH                  301
#define IDM_HELPHELP                    302
#define IDM_ABOUT                       303
#define IDM_CommandX                    310
#define IDM_CommandXLast                399
#define DLG_TimeControl                 400
#define ABOUTBOX_Version                401
#define OPT_TCUseMoves                  402
#define OPT_TCUseInc                    403
#define OPT_TCitext1                    405
#define OPT_TCitext2                    406
#define OPT_TCInc                       407
#define OPT_TCitext3                    408
#define OPT_TCTime2                     409
#define OPT_TCOdds1                     410
#define OPT_TCOdds2                     411
#define OPT_TCUseFixed                  412
#define OPT_TCFixed                     413
#define OPT_TCftext                     414
#define DLG_PremoveOptions              450
#define DLG_GeneralOptions              453
#define DLG_IcsOptions                  454
#define DLG_BoardOptions                455
#define DLG_Fonts                       456
#define DLG_NewGameFRC                  457
#define DLG_GameListOptions             458
#define DLG_MoveHistory                 459
#define DLG_EvalGraph                   461
#define DLG_EngineOutput                463
#define DLG_EnginePlayOptions           464
#define IDI_WHITE_14                    466
#define IDI_BLACK_14                    467
#define DLG_OptionsUCI                  467
#define IDI_PONDER_14                   468
#define IDI_TRANS_14                    469
#define IDI_CLOCK_14                    470
#define IDI_UNKNOWN_14                  471
#define IDI_BALOON_14                   472
#define IDI_ANALYZE_14                  473
#define IDI_ANALYZE2_14                 474
#define DLG_Promotion                   500
#define PB_Queen                        502
#define PB_Rook                         503
#define PB_Bishop                       504
#define PB_Knight                       505
#define PB_Chancellor                   506 /* [HGM] Capablanca pieces */
#define PB_Archbishop                   507
#define IDC_Yes                         520
#define IDC_No                          521
#define IDC_Centaur                     522
#define EP_White                        600
#define EP_WhitePawn                    601
#define EP_WhiteKnight                  602
#define EP_WhiteBishop                  603
#define EP_WhiteRook                    604
#define EP_WhiteQueen                   605
#define EP_Black                        606
#define EP_BlackPawn                    607
#define EP_BlackKnight                  608
#define EP_BlackBishop                  609
#define EP_BlackRook                    610
#define EP_BlackQueen                   611
#define EP_EmptySquare                  612
#define EP_ClearBoard                   613
#define EP_WhiteKing                    614
#define EP_BlackKing                    615
#define DP_Pawn                         616
#define DP_Knight                       617
#define DP_Bishop                       618
#define DP_Rook                         619
#define DP_Queen                        620

#define EP_WhiteCardinal                630
#define EP_WhiteMarshall                631
#define EP_WhiteAlfil                   632
#define EP_WhiteCannon                  633
#define EP_WhiteFerz                    634
#define EP_WhiteWazir                   635
#define EP_BlackCardinal                640
#define EP_BlackMarshall                641
#define EP_BlackAlfil                   642
#define EP_BlackCannon                  643
#define EP_BlackFerz                    644
#define EP_BlackWazir                   645
#define EP_Promote                      650
#define EP_Demote                       651

#define DLG_LoadOptions                 700
#define DLG_SaveOptions                 800
#define OPT_PGN                         802
#define OPT_Old                         803
#define DLG_CommPort                    900
#define OPT_Port                        901
#define OPT_DataRate                    902
#define OPT_Bits                        903
#define OPT_Parity                      904
#define OPT_StopBits                    905
#define OPT_Flow                        910
#define OPT_SerialHelp                  911
#define DLG_BoardSize                   1000
#define OPT_Small                       1001
#define OPT_SizeSmall                   1001
#define OPT_Medium                      1002
#define OPT_SizeBulky                   1002
#define OPT_Large                       1003
#define DLG_EditComment                 1004
#define OPT_ClearComment                1005
#define OPT_EditComment                 1006
#define OPT_CommentText                 1007
#define DLG_ViewComment                 1008
#define DLG_GameList                    1009
#define OPT_GameListPrev                1010
#define OPT_GameListText                1011
#define OPT_GameListLoad                1012
#define OPT_GameListNext                1013
#define OPT_GameListClose               1014
#define DLG_EditTags                    1015
#define OPT_TagsText                    1016
#define DLG_Analysis                    1017
#define OPT_AnalysisText                1018
#define DLG_Error                       1019
#define OPT_ErrorIcon                   1020
#define IDD_DIALOG1                     1021
#define DLG_ConsoleRich                 1022
#define IDC_EDIT1                       1023
#define OPT_DarkSquareColor             1023
#define IDC_GameListFilter              1023
#define IDC_NFG_Edit                    1023
#define IDC_EpDrawMoveCount             1023
#define IDC_PolyglotDir                 1023
#define OPT_ConsoleText                 1024
#define OPT_LightSquareColor            1024
#define OPT_CommandInput                1025
#define OPT_WhitePieceColor             1025
#define OPT_QuestionInput               1026
#define OPT_BlackPieceColor             1026
#define OPT_ChessEngineName             1027
#define OPT_HighlightSquareColor        1027
#define OPT_WavFileName                 1028
#define OPT_PremoveHighlightColor       1028
#define OPT_IndexNumber                 1029
#define OPT_SampleLightSquare           1029
#define OPT_Move                        1030
#define OPT_SampleDarkSquare            1030
#define OPT_PremoveWhiteText            1031
#define IDC_EDIT2                       1032
#define IDC_EpAdjudicationThreshold     1032
#define IDC_HashSize                    1032
#define OPT_ConsoleInput                1033
#define OPT_AdditionalOptions           1034
#define OPT_PremoveBlackText            1035
#define OPT_ErrorText                   1036
#define OPT_IcsAlarmTime                1037
#define OPT_Name                        1038
#define DLG_Console                     1100
#define DLG_PromotionKing               1102
#define DLG_Colorize                    1106
#define DLG_Command                     1122
#define DLG_Question                    1123
#define DLG_Startup                     1124
#define DLG_Sound                       1127
#define DLG_IndexNumber                 1149
#define DLG_TypeInMove                  1151
#define DLG_TypeInName                  1152
#define OPT_IndexNumberOld              1155
#define IDM_Rematch                     1203
#define IDA_PAGEUP                      1216
#define IDA_PAGEDOWN                    1217
#define IDA_CTRLHOME                    1218
#define IDA_CTRLEND                     1219
#define IDA_TAB                         1221
#define IDM_SaveSettings                1223
#define IDM_Iconize                     1224
#define IDM_DirectCommand1              1226
#define IDM_DirectCommand2              1227
#define IDM_Copy                        1229
#define IDM_Paste                       1230
#define IDM_MatchX                      1231
#define IDM_ObserveX                    1232
#define IDM_FingerX                     1233
#define IDM_TellX                       1234
#define IDM_QuickPaste                  1235
#define IDM_MessageX                    1237
#define IDM_VarsX                       1238
#define IDM_Cut                         1240
#define IDM_Undo                        1242
#define IDM_SelectAll                   1243
#define IDM_SaveSettingsOnExit          1280
#define IDM_LoadNextPosition            1286
#define IDM_ReloadPosition              1287
#define IDM_LoadPrevPosition            1288
#define IDM_TypeInMove                  1291
#define IDM_PopupExitMessage            1292
#define IDM_Training                    1293
#define IDM_GeneralOptions              1299
#define IDM_BoardOptions                1300
#define IDM_Fonts                       1301
#define IDM_UserAdjudication_White      1302
#define IDM_UserAdjudication_Black      1303
#define IDM_UserAdjudication_Draw       1304
#define IDM_NewGameFRC                  1305
#define IDM_GameListOptions             1306
#define PB_King                         1307
#define IDM_ShowMoveHistory             1307
#define IDM_PasteAny                    1309
#define IDM_ShowEvalGraph               1310
#define IDM_CopyGameListToClipboard     1311
#define OPT_Bold                        1312
#define IDM_ShowEngineOutput            1312
#define OPT_Italic                      1313
#define IDM_EnginePlayOptions           1313
#define OPT_Underline                   1314
#define IDM_OptionsUCI                  1314
#define OPT_Strikeout                   1315
#define OPT_ChooseColor                 1316
#define OPT_Sample                      1318
#define OPT_SampleSShout                1319
#define OPT_CancelComment               1320
#define OPT_SampleChannel1              1320
#define OPT_SampleChannel               1321
#define OPT_SampleKibitz                1322
#define OPT_SampleTell                  1324
#define OPT_EditTags                    1325
#define OPT_SampleChallenge             1325
#define OPT_TagsCancel                  1326
#define OPT_SampleRequest               1326
#define OPT_CommandText                 1327
#define OPT_QuestionText                1327
#define OPT_SampleSeek                  1327
#define OPT_ChessEngine                 1328
#define OPT_SampleNormal                1328
#define OPT_ChessServer                 1329
#define OPT_View                        1330
#define OPT_ChessServerName             1331
#define OPT_NoSound                     1333
#define OPT_DefaultBeep                 1334
#define OPT_SystemSound                 1335
#define OPT_BuiltInSound                1336
#define OPT_WavFile                     1337
#define OPT_BuiltInSoundName            1339
#define OPT_SystemSoundName             1340
#define OPT_BrowseSound                 1341
#define OPT_PlaySound                   1342
#define OPT_AVBrowse                    1343
#define OPT_SecondChessEngineName       1344
#define OPT_AnyAdditional               1345
#define OPT_Premove                     1346
#define OPT_PremoveWhite                1347
#define OPT_PremoveBlack                1348
#define OPT_IcsAlarm                    1349
#define CBO_Sounds                      1350
#define OPT_DefaultSounds               1351
#define OPT_AlwaysOnTop                 1352
#define OPT_AutoFlag                    1353
#define OPT_AlwaysQueen                 1354
#define OPT_AutoComment                 1354
#define OPT_AnimateDragging             1355
#define OPT_AutoObserve                 1355
#define OPT_AnimateMoving               1356
#define OPT_GetMoveList                 1356
#define OPT_AutoFlipView                1357
#define OPT_LocalLineEditing            1357
#define OPT_HighlightDragging           1358
#define OPT_QuietPlay                   1358
#define OPT_HighlightLastMove           1359
#define OPT_PeriodicUpdates             1360
#define OPT_ChooseLightSquareColor      1360
#define OPT_PonderNextMove              1361
#define OPT_ChooseDarkSquareColor       1361
#define OPT_PopupExitMessage            1362
#define OPT_ChooseWhitePieceColor       1362
#define OPT_PopupMoveErrors             1363
#define OPT_ChooseBlackPieceColor       1363
#define OPT_ShowCoordinates             1364
#define OPT_ChooseHighlightSquareColor  1364
#define OPT_ShowThinking                1365
#define OPT_ChoosePremoveHighlightColor 1365
#define OPT_TestLegality                1366
#define OPT_Blindfold                   1367
#define OPT_SizeTiny                    1368
#define OPT_SizeTeeny                   1369
#define OPT_SizeDinky                   1370
#define OPT_SizePetite                  1371
#define OPT_SizeSlim                    1372
#define OPT_SizeMediocre                1374
#define OPT_SizeMiddling                1375
#define OPT_SizeAverage                 1376
#define OPT_SizeModerate                1377
#define OPT_SizeMedium                  1378
#define OPT_SizeLarge                   1379
#define OPT_SizeBig                     1380
#define OPT_SizeHuge                    1381
#define OPT_SizeGiant                   1382
#define OPT_SizeColossal                1383
#define OPT_SizeTitanic                 1384
#define OPT_Monochrome                  1385
#define OPT_DefaultBoardColors          1386
#define OPT_ChooseShoutColor            1387
#define OPT_ChooseSShoutColor           1388
#define OPT_ChooseChannel1Color         1389
#define OPT_ChooseChannelColor          1390
#define OPT_ChooseKibitzColor           1391
#define OPT_ChooseBackgroundColor       1392
#define OPT_ChooseTellColor             1393
#define OPT_ChooseChallengeColor        1394
#define OPT_ChooseRequestColor          1395
#define OPT_ChooseSeekColor             1396
#define OPT_ChooseNormalColor           1397
#define OPT_DefaultColors               1398
#define IDM_Minimize                    1400
#define OPT_SampleShout                 1400
#define IDM_Sounds                      1401
#define OPT_SampleClockFont             1401
#define IDM_IcsOptions                  1402
#define OPT_SampleCoordFont             1402
#define OPT_DontColorize                1403
#define OPT_SampleMessageFont           1403
#define OPT_SampleTagFont               1404
#define OPT_SampleCommentsFont          1405
#define OPT_SampleConsoleFont           1406
#define OPT_MessageFont                 1407
#define OPT_ClockFont                   1408
#define OPT_CoordFont                   1409
#define OPT_EditTagsFont                1410
#define OPT_CommentsFont                1411
#define OPT_MessageFont5                1412
#define OPT_ChooseClockFont             1413
#define OPT_ChooseMessageFont           1414
#define OPT_ChooseCoordFont             1415
#define OPT_ChooseTagFont               1416
#define OPT_ChooseCommentsFont          1417
#define OPT_ChooseConsoleFont           1418
#define OPT_DefaultFonts                1419
#define OPT_ChooseMoveHistoryFont       1420
#define OPT_AutoRaiseBoard              1421
#define OPT_SampleMoveHistoryFont       1421
#define OPT_ShowButtonBar               1422
#define OPT_MessageFont6                1422
#define OPT_SaveExtPGN                  1423
#define OPT_HideThinkFromHuman          1424
#define IDC_GameListDoFilter            1425
#define IDC_NFG_Random                  1426
#define IDC_NFG_Label                   1427
#define IDC_GameListTags                1428
#define IDC_GLT                         1429
#define IDC_GLT_Up                      1430
#define IDC_GLT_Down                    1431
#define IDC_GLT_Restore                 1432
#define IDC_GLT_Default                 1433
#define IDC_GLT_RestoreTo               1434
#define IDC_MoveHistory                 1435
#define OPT_OutOfBookInfo               1436
#define OPT_ExtraInfoInMoveHistory      1437
#define OPT_HighlightMoveArrow          1438
#define OPT_AutoLogo			1439
#define IDC_BUTTON1                     1440
#define IDC_BrowseForPolyglotDir        1440
#define IDC_BrowseForEGTB               1441
#define IDC_BrowseForBook               1442
#define IDC_EngineMemo1                 1443
#define IDC_EngineMemo2                 1444
#define IDC_EngineLabel1                1445
#define IDC_EngineLabel2                1446
#define IDC_EpShowThinking              1447
#define IDC_EpHideThinkingHuman         1448
#define IDC_EpPonder                    1449
#define IDC_EpPeriodicUpdates           1450
#define IDC_Engine1_NPS                 1451
#define IDC_Engine2_NPS                 1452
#define IDC_Color1                      1459
#define IDC_Color2                      1460
#define IDC_StateIcon1                  1461
#define IDC_StateData1                  1462
#define IDC_StateData2                  1463
#define IDC_StateIcon2                  1464
#define IDC_PathToEGTB                  1466
#define IDC_SizeOfEGTB                  1467
#define IDC_BookFile                    1469
#define IDC_UseBook                     1470
#define IDC_OwnBook1                    1471
#define IDC_OwnBook2                    1472
#define IDC_Cores                       1473
#define IDC_BookDep                     1474
#define IDC_BookStr                     1475
#define IDC_Games                       1476
#define DLG_NewVariant                  1500
#define OPT_VariantGothic               1501
#define OPT_VariantCrazyhouse           1502
#define OPT_VariantBughouse             1503
#define OPT_VariantCourier              1504
#define OPT_VariantShatranj             1505
#define OPT_VariantShogi                1506
#define OPT_VariantXiangqi              1507
#define OPT_VariantCapablanca           1508
#define OPT_VariantTwoKings             1509
#define OPT_VariantKnightmate           1510
#define OPT_VariantLosers               1511
#define OPT_VariantSuicide              1512
#define OPT_VariantAtomic               1513
#define OPT_VariantNormal               1514
#define OPT_VariantFairy                1515
#define OPT_VariantFRC                  1516
#define OPT_VariantCylinder             1517
#define OPT_VariantFalcon               1518
#define OPT_VariantCRC                  1519
#define OPT_VariantBerolina             1520
#define OPT_VariantSuper                1521
#define OPT_VariantJanus                1522
#define OPT_VariantWildcastle           1523
#define OPT_VariantNocastle             1524
#define OPT_VariantGiveaway             1525
#define OPT_Variant3Check               1526
#define OPT_VariantGreat                1527
#define OPT_VariantTwilight             1528
#define OPT_VariantMakruk               1529
#define OPT_VariantSChess               1530
#define OPT_VariantSpartan              1531
#define OPT_VariantGrand                1534
#define IDC_Files                       1550
#define IDC_Ranks                       1551
#define IDC_Holdings                    1552
#define IDC_TestClaims                  1600
#define IDC_DetectMates                 1601
#define IDC_MaterialDraws               1602
#define IDC_TrivialDraws                1603
#define IDC_RuleMoves                   1604
#define IDC_DrawRepeats                 1605
#define IDC_ScoreAbs1                   1606
#define IDC_ScoreAbs2                   1607
#define IDM_FlipClock                   1700
#define OPT_AllWhite                    1701
#define OPT_UpsideDown                  1702
#define DLG_Chat			1720
#define IDC_Change			1721
#define IDC_ChatPartner			1722
#define IDC_ChatMemo			1723
#define OPT_ChatInput			1724
#define IDC_Clear			1725
#define IDC_Send			1726
#define IDM_NewChat			1727
#define IDC_Focus1			1730
#define IDC_Focus2			1731
#define IDC_Focus3			1732
#define IDC_Focus4			1733
#define OPT_SeekGraph			1750
#define OPT_AutoRefresh			1751
#define OPT_BgObserve			1752
#define OPT_DualBoard			1753
#define OPT_SmartMove			1754
#define OPT_StartupChatBoxes		1755
#define OPT_AutoKibitz			1756
#define IDC_SPECIFY_ENG_STATIC          1814
#define IDC_SPECIFY_SERVER_STATIC       1815
#define OPT_MESS                        1818
#define IDM_Engine1Options		1890
#define IDM_Engine2Options		1891
#define IDM_EditBook			1892
#define IDM_Tourney			1894
#define IDC_STATIC                      -1
// static strings that were made dynamic to allow run-time translation
#define IDC_Babble			1900
#define GPB_Factors			1901
#define IDC_Factor1			1902
#define IDC_Factor2			1903
#define IDC_Directories			1904
#define IDC_IndexNr			1905
#define IDC_Port			1906
#define IDC_Rate			1907
#define IDC_Bits			1908
#define IDC_Parity			1909
#define IDC_Stop			1910
#define IDC_Flow			1911
#define IDC_ChessBoard			1912
#define IDC_Welcome			1913
#define IDC_Index			1914
#define IDC_Event			1915
#define IDC_Sec				1916
#define IDC_Boxes			1917
#define GPB_Premove			1918
#define GPB_General			1919
#define GPB_Colors			1920
#define GPB_Alarm			1921
#define IDC_Light			1922
#define IDC_Dark			1923
#define IDC_White			1924
#define IDC_Black			1925
#define IDC_High			1926
#define IDC_PreHigh			1927
#define GPB_Size			1928
#define IDC_Height			1929
#define IDC_Width			1930
#define IDC_Hand			1931
#define IDC_Pieces			1932
#define IDC_Def				1933
#define GPB_Board			1934
#define GPB_Current			1935
#define GPB_All				1936
#define IDC_Partner			1937
#define IDC_Draw			1938
#define IDC_Threshold			1939
#define IDC_Moves			1940
#define IDC_Centi			1941
#define IDC_Rule			1942
#define IDC_Repeats			1943
#define GPB_Adjudications		1944	
#define GPB_Apply			1945
#define IDC_PolyDir			1946
#define IDC_Hash			1947
#define IDC_Path			1948
#define IDC_Cache			1949
#define IDC_CPU				1950
#define IDC_Depth			1951
#define IDC_Variation			1952
#define IDC_DefGames			1953
#define GPB_Variant			1954
#define OPT_MessageFont7                1955
#define OPT_SampleGameListFont          1956
#define OPT_ChooseGameListFont          1957
#define OPT_elo1                        1958
#define OPT_elo2                        1959
#define OPT_date                        1960
#define OPT_elo1t                       1961
#define OPT_elo2t                       1962
#define OPT_datet                       1963
#define OPT_thresholds                  1964
#define OPT_Exact                       1965
#define OPT_Subset                      1966
#define OPT_Struct                      1967
#define OPT_Material                    1968
#define OPT_Range                       1969
#define OPT_Difference                  1970
#define OPT_Stretch                     1971
#define OPT_Stretcht                    1972
#define OPT_Reversed                    1973
#define OPT_SearchMode                  1974
#define OPT_Mirror                      1975
#define OPT_Bitmaps                     1976
#define OPT_PieceFont                   1977
#define OPT_MessageFont8                1978
#define OPT_SamplePieceFont             1979
#define OPT_ChoosePieceFont             1980
#define OPT_GameListFind                1981


// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        468
#define _APS_NEXT_COMMAND_VALUE         1315
#define _APS_NEXT_CONTROL_VALUE         1471
#define _APS_NEXT_SYMED_VALUE           1404
#endif
#endif
